@@ -16,10 +16,10 @@ get_report <- function(path, query, token, by = NULL) {
     }
     if (!grepl("^ga:", query$profileId))
         query$profileId <- paste0("ga:", query$profileId)
-    if (!is.null(by))
-        json_content <- fetch_by(path, query, by, token)
-    else
+    if (is.null(by))
         json_content <- get_data(path, query, token)
+    else
+        json_content <- fetch_by(path, query, by, token)
     if (is.null(json_content$rows) || length(json_content$rows) == 0) {
         message("No results were obtained.")
         return(invisible(NULL))
@@ -41,8 +41,8 @@ get_report <- function(path, query, token, by = NULL) {
     attr(res, "query") <- json_content$query
     attr(res, "sampled") <- json_content$containsSampledData
     if (!is.null(json_content$contains.sampled.data) && isTRUE(json_content$contains.sampled.data)) {
-        attr(res, "sample.size") <- json_content$sampleSize
-        attr(res, "sample.space") <- json_content$sampleSpace
+        attr(res, "sampleSize") <- json_content$sampleSize
+        attr(res, "sampleSpace") <- json_content$sampleSpace
         samplePerc <- json_content$sampleSize / json_content$sampleSpace * 100
         if (is.null(by))
             warning(sprintf("Data contains sampled data. Used %d sessions (%1.0f%% of sessions). Try to use the 'fetch.by' param to avoid sampling.", json_content$sampleSize, samplePerc), call. = FALSE)
